@@ -2,7 +2,7 @@ CREATE DATABASE foo;
 USE foo;
 
 CREATE USER 'foo'@'127.0.0.1' IDENTIFIED BY 'bar';
-GRANT ALL PRIVILEGES ON foo.* TO 'foo'@'127.0.0.1';
+GRANT ALL PRIVILEGES ON *.* TO 'foo'@'127.0.0.1';
 
 -- from mysql_init.sh
 CREATE TABLE department(department_id int, department_name text, PRIMARY KEY (department_id));
